[0.10] gst-editing-services: trackobject: Some documentation fixing

Thibault Saunier tsaunier at kemper.freedesktop.org
Sat Apr 7 18:29:00 PDT 2012


Module: gst-editing-services
Branch: 0.10
Commit: c783f4140af3597da7aadcfa2f92732512150b11
URL:    http://cgit.freedesktop.org/gstreamer/gst-editing-services/commit/?id=c783f4140af3597da7aadcfa2f92732512150b11

Author: Thibault Saunier <thibault.saunier at collabora.com>
Date:   Mon Jan 30 22:55:59 2012 +0100

trackobject: Some documentation fixing

---

 ges/ges-track-object.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/ges/ges-track-object.c b/ges/ges-track-object.c
index c41e918..3fb0cc9 100644
--- a/ges/ges-track-object.c
+++ b/ges/ges-track-object.c
@@ -868,17 +868,17 @@ ges_track_object_get_track (GESTrackObject * object)
 /**
  * ges_track_object_set_timeline_object:
  * @object: The #GESTrackObject to set the parent to
  * @tlobj: The #GESTimelineObject, parent of @tlobj or %NULL
  *
  * Set the #GESTimelineObject to which @object belongs.
  */
 void
 ges_track_object_set_timeline_object (GESTrackObject * object,
-    GESTimelineObject * tlobj)
+    GESTimelineObject * tlobject)
 {
-  GST_DEBUG ("object:%p, timeline-object:%p", object, tlobj);
+  GST_DEBUG ("object:%p, timeline-object:%p", object, tlobject);
 
-  object->priv->timelineobj = tlobj;
+  object->priv->timelineobj = tlobject;
 }
 
 /**
@@ -868,17 +868,17 @@ ges_track_object_get_track (GESTrackObject * object)
  * ges_track_object_set_timeline_object:
  * @object: The #GESTrackObject to set the parent to
- * @tlobj: The #GESTimelineObject, parent of @tlobj or %NULL
+ * @tlobject: The #GESTimelineObject, parent of @tlobj or %NULL
  *
  * Set the #GESTimelineObject to which @object belongs.



More information about the gstreamer-commits mailing list